@@ -23,17 +23,17 @@ class IConfigurationService(Interface):
     def reload():
         """ Reload all registered models and configuration files """
 
-    def get(name, prefix=None):
+    def get(name, domain=None):
         """ Return the value of a configuration option for a given key.
             'name' is either a full dotted name or added to a dotted
-             prefix.
+             domain.
         """
 
     def getConfiguration():
         """ Return all configuration items as dict """
 
-    def getConfigurationForPrefix(prefix):
-        """ Return all configuration items as dict for a given prefix"""
+    def getConfigurationForDomain(domain):
+        """ Return all configuration items as dict for a given domain"""
 
     def shutdown():
         """ Perform actions upon system shutdown """
