@@ -42,6 +42,8 @@ class ConfigurationService(object):
     def __init__(self, watch=False):
         self._clear()
         self.watch = watch # Watch configuration file changes
+        self.parser = None
+        self.opts = None
 
         # start notification service
         self.notify_wm = None
